#!/bin/sh

passwd_file=/etc/passwd
home_dir=/mnt/HD_a2/home

if [ $# -lt 1 -o $# -gt 2 ]; then
    echo "Usage: $(basename $0) user [home-dir]"
    echo " Default home directory: ${home_dir}/user"
    exit 1
fi

user=$1
if [ $# -eq 2 ]; then
    newhome=$2
else
    newhome=${home_dir}/${user}
fi

grep "^${user}:" ${passwd_file} >/dev/null 2>/dev/null
if [ $? -ne 0 ]; then
    echo "${user} not found in ${passwd_file}"
    exit 1
fi

if [ ! -r ${passwd_file}.orig ]; then
    echo "Saving original passwd file to ${passwd_file}.orig"
    cat ${passwd_file} >${passwd_file}.orig
fi

echo "Setting home directory of user ${user} to ${newhome}"
cat ${passwd_file} >${passwd_file}.1
cat ${passwd_file}.1 | awk -F: -vOFS=":" "{ if (\$1 == \"$user\") {\$6 = \"$newhome\"} print \$0 }" >${passwd_file}

if [ ! -d ${newhome} ]; then
    echo "Creating directory ${newhome}"
    mkdir -p ${newhome}
fi
chown ${user} ${newhome}
chmod 0755 ${newhome}

