#!/bin/sh

unfsd_start() {
    if [ -x "${BINDIR}/rpc.portmap" ]; then
        echo "Starting rpc.portmap..."
        ${BINDIR}/rpc.portmap
    else
        echo "ERROR: rpc.portmap not found"
    fi
    
    exports=${ETCDIR}/exports
    if [ ! -r "$exports" ]; then
        echo "Creating default exports file..."
        ip=$(ifconfig egiga0 | awk '/inet addr/ { print substr($2, 6) }')
        cnet=$(echo $ip | cut -d. -f1-3).0/24
        options="rw,no_root_squash"
        
        for i in / ${VOL1} ${VOL2}; do
            if [ -d ${i} ]; then
                echo "${i} ${cnet}(${options})" >>${exports}
            fi
        done
        cat ${exports}
    fi
    
    if [ -x "${BINDIR}/unfsd" ]; then
        echo "Starting unfsd..."
        ${BINDIR}/unfsd -e ${exports} -d 1>${LOGDIR}/unfsd.log 2>&1 &
    else
        echo "ERROR: unfsd not found or not executable"
    fi
}

unfsd_stop() {
    killall unfsd
    killall portmap
}


unfsd_status() {
    if [ -n "$(pidof unfsd)" ]; then
        echo "running"
    else
        echo "stopped"
    fi
}

case "$1" in
    stop)
        unfsd_stop
        ;;
    restart)
        unfsd_stop
        sleep 1
        unfsd_start
        ;;
    status)
        unfsd_status
        ;;
    start|'')
        unfsd_start
        ;;
    *)
        echo "Usage: $0 start|stop|restart|status"
        ;;
esac
